@@ -31,10 +31,8 @@
 #include <KCodecs>
 
 #include <QDebug>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <QStringDecoder>
-#endif
-#include <QTextCodec>
+#include <QStringEncoder>
 
 using namespace KMime;
 
@@ -369,16 +367,6 @@ QString Content::decodedText(bool trimText, bool removeTrailingNewlines)
       return {};
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QTextCodec *codec = QTextCodec::codecForName(contentType()->charset());
-    if (codec == nullptr) {   // no suitable codec found => try local settings and hope the best ;-)
-        codec = QTextCodec::codecForLocale();
-        QByteArray chset = codec->name();
-        contentType()->setCharset(chset);
-    }
-
-    QString s = codec->toUnicode(d_ptr->body.data(), d_ptr->body.length());
-#else
     QStringDecoder codec(contentType()->charset().constData());
     if (!codec.isValid()) {   // no suitable codec found => try local settings and hope the best ;-)
         codec = QStringDecoder(QStringDecoder::System);
@@ -387,7 +375,6 @@ QString Content::decodedText(bool trimText, bool removeTrailingNewlines)
     }
 
     QString s = codec.decode(d_ptr->body);
-#endif
 
     if (trimText || removeTrailingNewlines) {
         int i;
@@ -414,15 +401,15 @@ QString Content::decodedText(bool trimText, bool removeTrailingNewlines)
 
 void Content::fromUnicodeString(const QString &s)
 {
-    QTextCodec *codec = QTextCodec::codecForName(contentType()->charset());
+    QStringEncoder codec(contentType()->charset().constData());
 
-    if (!codec) {   // no suitable codec found => try local settings and hope the best ;-)
-        codec = QTextCodec::codecForLocale();
-        QByteArray chset = codec->name();
+    if (!codec.isValid()) {   // no suitable codec found => try local settings and hope the best ;-)
+        codec = QStringEncoder(QStringEncoder::System);
+        QByteArray chset = codec.name();
         contentType()->setCharset(chset);
     }
 
-    d_ptr->body = codec->fromUnicode(s);
+    d_ptr->body = codec.encode(s);
     contentTransferEncoding()->setDecoded(true);   //text is always decoded
 }
 
@@ -444,31 +431,27 @@ Content *Content::textContent()
     return ret;
 }
 
-QVector<Content*> Content::attachments()
-{
-    QVector<Content*> result;
+QList<Content *> Content::attachments() {
+    QList<Content *> result;
 
     auto ct = contentType(false);
     if (ct && ct->isMultipart() &&
         !ct->isSubtype("related") /* && !ct->isSubtype("alternative")*/) {
-      const QVector<Content *> contentsList = contents();
-      result.reserve(contentsList.count());
-      for (Content *child : contentsList) {
-        if (isAttachment(child)) {
-          result.push_back(child);
-        } else {
-          result += child->attachments();
-        }
+        const QList<Content *> contentsList = contents();
+        result.reserve(contentsList.count());
+        for (Content *child : contentsList) {
+            if (isAttachment(child)) {
+                result.push_back(child);
+            } else {
+                result += child->attachments();
+            }
       }
     }
 
     return result;
 }
 
-QVector<Content*> Content::contents() const
-{
-    return d_ptr->contents();
-}
+QList<Content *> Content::contents() const { return d_ptr->contents(); }
 
 void Content::replaceContent(Content *oldContent, Content *newContent)
 {
@@ -497,7 +480,7 @@ void Content::addContent(Content *c, bool prepend)
     // If this message is single-part; make it multipart first.
     if (d->multipartContents.isEmpty() && !contentType()->isMultipart()) {
         // The current body will be our first sub-Content.
-        auto *main = new Content(this);
+        auto main = new Content(this);
 
         // Move the MIME headers to the newly created sub-Content.
         // NOTE: The other headers (RFC5322 headers like From:, To:, as well as X-headers
@@ -614,10 +597,7 @@ void Content::changeEncoding(Headers::contentEncoding e)
     }
 }
 
-QVector<Headers::Base*> Content::headers() const
-{
-    return d_ptr->headers;
-}
+QList<Headers::Base *> Content::headers() const { return d_ptr->headers; }
 
 Headers::Base *Content::headerByType(const char *type) const
 {
@@ -632,11 +612,10 @@ Headers::Base *Content::headerByType(const char *type) const
     return nullptr; // Not found.
 }
 
-QVector<Headers::Base*> Content::headersByType(const char *type) const
-{
+QList<Headers::Base *> Content::headersByType(const char *type) const {
     Q_ASSERT(type && *type);
 
-    QVector<Headers::Base*> result;
+    QList<Headers::Base *> result;
 
     for (Headers::Base *h : std::as_const(d_ptr->headers)) {
         if (h->is(type)) {
@@ -835,7 +814,7 @@ Content *Content::parent() const
 
 Content *Content::topLevel() const
 {
-    auto *top = const_cast<Content *>(this);
+    auto top = const_cast<Content *>(this);
     Content *c = parent();
     while (c) {
         top = c;
@@ -894,11 +873,10 @@ void ContentPrivate::clearBodyMessage()
     bodyAsMessage.reset();
 }
 
-QVector<Content*> ContentPrivate::contents() const
-{
+QList<Content *> ContentPrivate::contents() const {
     Q_ASSERT(multipartContents.isEmpty() || !bodyAsMessage);
     if (bodyAsMessage) {
-        return QVector<Content*>() << bodyAsMessage.data();
+      return QList<Content *>() << bodyAsMessage.data();
     } else {
         return multipartContents;
     }
@@ -934,7 +912,7 @@ bool ContentPrivate::parseUuencoded(Content *q)
         // Add the plain text part first.
         Q_ASSERT(multipartContents.isEmpty());
         {
-            auto *c = new Content(q);
+            auto c = new Content(q);
             c->contentType()->setMimeType("text/plain");
             c->contentTransferEncoding()->setEncoding(Headers::CE7Bit);
             c->setBody(uup.textPart());
@@ -943,7 +921,7 @@ bool ContentPrivate::parseUuencoded(Content *q)
 
         // Now add each of the binary parts as sub-Contents.
         for (int i = 0; i < uup.binaryParts().count(); ++i) {
-            auto *c = new Content(q);
+            auto c = new Content(q);
             c->contentType()->setMimeType(uup.mimeTypes().at(i));
             c->contentType()->setName(QLatin1String(uup.filenames().at(i)), QByteArray(/*charset*/));
             c->contentTransferEncoding()->setEncoding(Headers::CEuuenc);
@@ -990,7 +968,7 @@ bool ContentPrivate::parseYenc(Content *q)
         // Add the plain text part first.
         Q_ASSERT(multipartContents.isEmpty());
         {
-            auto *c = new Content(q);
+            auto c = new Content(q);
             c->contentType()->setMimeType("text/plain");
             c->contentTransferEncoding()->setEncoding(Headers::CE7Bit);
             c->setBody(yenc.textPart());
@@ -999,7 +977,7 @@ bool ContentPrivate::parseYenc(Content *q)
 
         // Now add each of the binary parts as sub-Contents.
         for (int i = 0; i < yenc.binaryParts().count(); i++) {
-            auto *c = new Content(q);
+            auto c = new Content(q);
             c->contentType()->setMimeType(yenc.mimeTypes().at(i));
             c->contentType()->setName(QLatin1String(yenc.filenames().at(i)), QByteArray(/*charset*/));
             c->contentTransferEncoding()->setEncoding(Headers::CEbinary);
@@ -1042,7 +1020,7 @@ bool ContentPrivate::parseMultipart(Content *q)
     body.clear();
     const auto parts = mpp.parts();
     for (const QByteArray &part : parts) {
-        auto *c = new Content(q);
+        auto c = new Content(q);
         c->setContent(part);
         c->setFrozen(frozen);
         c->parse();
