@@ -51,11 +51,11 @@ namespace HeaderParsing
 
   @return true if the input string was successfully decode; false otherwise.
 */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseEncodedWord(const char *&scursor,
-                                   const char *const send,
-                                   QString &result, QByteArray &language,
-                                   QByteArray &usedCS, const QByteArray &defaultCS = QByteArray(),
-                                   bool forceCS = false);
+[[nodiscard]] KMIME_EXPORT bool
+parseEncodedWord(const char *&scursor, const char *const send, QString &result,
+                 QByteArray &language, QByteArray &usedCS,
+                 const QByteArray &defaultCS = QByteArray(),
+                 bool forceCS = false);
 
 //
 // The parsing squad:
@@ -64,15 +64,18 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseEncodedWord(const char *&scursor,
 /** You may or may not have already started parsing into the
     atom. This function will go on where you left off.
  */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseAtom(const char *&scursor, const char *const send,
-                            QByteArray &result, bool allow8Bit = false);
+[[nodiscard]] KMIME_EXPORT bool parseAtom(const char *&scursor,
+                                          const char *const send,
+                                          QByteArray &result,
+                                          bool allow8Bit = false);
 
 /**
  * More efficient overload, to avoid a copy of the substring
  */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseAtom(const char *&scursor, const char *const send,
-                            QPair<const char *, int> &result,
-                            bool allow8Bit = false);
+[[nodiscard]] KMIME_EXPORT bool parseAtom(const char *&scursor,
+                                          const char *const send,
+                                          QPair<const char *, int> &result,
+                                          bool allow8Bit = false);
 
 enum ParseTokenFlag {
     ParseTokenNoFlag = 0,
@@ -83,24 +86,25 @@ Q_DECLARE_FLAGS(ParseTokenFlags, ParseTokenFlag)
 
 /** You may or may not have already started parsing into the
     token. This function will go on where you left off. */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseToken(const char *&scursor, const char *const send,
-                             QByteArray &result, ParseTokenFlags flags = ParseTokenNoFlag);
+[[nodiscard]] KMIME_EXPORT bool
+parseToken(const char *&scursor, const char *const send, QByteArray &result,
+           ParseTokenFlags flags = ParseTokenNoFlag);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseToken(const char *&scursor, const char *const send,
-                             QPair<const char *, int> &result,
-                             ParseTokenFlags flags = ParseTokenNoFlag);
+[[nodiscard]] KMIME_EXPORT bool
+parseToken(const char *&scursor, const char *const send,
+           QPair<const char *, int> &result,
+           ParseTokenFlags flags = ParseTokenNoFlag);
 
 /** @p scursor must be positioned after the opening openChar. */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseGenericQuotedString(const char *&scursor,
-        const char *const send,
-        QString &result, bool isCRLF,
-        const char openChar = '"',
-        const char closeChar = '"');
+[[nodiscard]] KMIME_EXPORT bool
+parseGenericQuotedString(const char *&scursor, const char *const send,
+                         QString &result, bool isCRLF,
+                         const char openChar = '"', const char closeChar = '"');
 
 /** @p scursor must be positioned right after the opening '(' */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseComment(const char *&scursor, const char *const send,
-                               QString &result, bool isCRLF = false,
-                               bool reallySave = true);
+[[nodiscard]] KMIME_EXPORT bool
+parseComment(const char *&scursor, const char *const send, QString &result,
+             bool isCRLF = false, bool reallySave = true);
 
 /**
   Parses a phrase.
@@ -117,8 +121,10 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseComment(const char *&scursor, const cha
 
   @return true if the input phrase was successfully parsed; false otherwise.
 */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parsePhrase(const char *&scursor, const char *const send,
-                              QString &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parsePhrase(const char *&scursor,
+                                            const char *const send,
+                                            QString &result,
+                                            bool isCRLF = false);
 
 /**
   Parses into the initial atom.
@@ -132,8 +138,10 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parsePhrase(const char *&scursor, const char
 
   @return true if the input phrase was successfully parsed; false otherwise.
 */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseDotAtom(const char *&scursor, const char *const send,
-                               QByteArray &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseDotAtom(const char *&scursor,
+                                             const char *const send,
+                                             QByteArray &result,
+                                             bool isCRLF = false);
 
 /**
   Eats comment-folding-white-space, skips whitespace, folding and comments
@@ -152,18 +160,24 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseDotAtom(const char *&scursor, const cha
 KMIME_EXPORT void eatCFWS(const char *&scursor, const char *const send,
                           bool isCRLF);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseDomain(const char *&scursor, const char *const send,
-                              QString &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseDomain(const char *&scursor,
+                                            const char *const send,
+                                            QString &result,
+                                            bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseObsRoute(const char *&scursor, const char *const send,
-                                QStringList &result, bool isCRLF = false,
-                                bool save = false);
+[[nodiscard]] KMIME_EXPORT bool
+parseObsRoute(const char *&scursor, const char *const send, QStringList &result,
+              bool isCRLF = false, bool save = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseAddrSpec(const char *&scursor, const char *const send,
-                                Types::AddrSpec &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseAddrSpec(const char *&scursor,
+                                              const char *const send,
+                                              Types::AddrSpec &result,
+                                              bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseAngleAddr(const char *&scursor, const char *const send,
-                                 Types::AddrSpec &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseAngleAddr(const char *&scursor,
+                                               const char *const send,
+                                               Types::AddrSpec &result,
+                                               bool isCRLF = false);
 
 /**
   Parses a single mailbox.
@@ -184,31 +198,34 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseAngleAddr(const char *&scursor, const c
 KMIME_EXPORT bool parseMailbox(const char *&scursor, const char *const send,
                                Types::Mailbox &result, bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseGroup(const char *&scursor, const char *const send,
-                             Types::Address &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseGroup(const char *&scursor,
+                                           const char *const send,
+                                           Types::Address &result,
+                                           bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseAddress(const char *&scursor, const char *const send,
-                               Types::Address &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseAddress(const char *&scursor,
+                                             const char *const send,
+                                             Types::Address &result,
+                                             bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseAddressList(const char *&scursor,
-                                   const char *const send,
-                                   Types::AddressList &result,
-                                   bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseAddressList(const char *&scursor,
+                                                 const char *const send,
+                                                 Types::AddressList &result,
+                                                 bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseParameterList(const char *&scursor,
-                                     const char *const send,
-                                     QMap<QString, QString> &result,
-                                     bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool
+parseParameterList(const char *&scursor, const char *const send,
+                   QMap<QString, QString> &result, bool isCRLF = false);
 
 /**
  * Extract the charset embedded in the parameter list if there is one.
  *
  * @since 4.5
  */
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseParameterListWithCharset(const char *&scursor,
-        const char *const send,
-        QMap<QString, QString> &result,
-        QByteArray &charset, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool
+parseParameterListWithCharset(const char *&scursor, const char *const send,
+                              QMap<QString, QString> &result,
+                              QByteArray &charset, bool isCRLF = false);
 
 /**
   Parses an integer number.
@@ -217,17 +234,22 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseParameterListWithCharset(const char *&s
   @param result the parsing result
   @returns The number of parsed digits (don't confuse with @p result!)
 */
-Q_REQUIRED_RESULT KMIME_EXPORT int parseDigits(const char *&scursor, const char *const send, int &result);
+[[nodiscard]] KMIME_EXPORT int parseDigits(const char *&scursor,
+                                           const char *const send, int &result);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseTime(const char *&scursor, const char *const send,
-                            int &hour, int &min, int &sec,
-                            long int &secsEastOfGMT,
-                            bool &timeZoneKnown, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool
+parseTime(const char *&scursor, const char *const send, int &hour, int &min,
+          int &sec, long int &secsEastOfGMT, bool &timeZoneKnown,
+          bool isCRLF = false);
 
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseDateTime(const char *&scursor, const char *const send,
-                                QDateTime &result, bool isCRLF = false);
-Q_REQUIRED_RESULT KMIME_EXPORT bool parseQDateTime(const char *&scursor, const char *const send,
-                                QDateTime &result, bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseDateTime(const char *&scursor,
+                                              const char *const send,
+                                              QDateTime &result,
+                                              bool isCRLF = false);
+[[nodiscard]] KMIME_EXPORT bool parseQDateTime(const char *&scursor,
+                                               const char *const send,
+                                               QDateTime &result,
+                                               bool isCRLF = false);
 
 /**
  * Extracts and returns the first header that is contained in the given byte array.
@@ -235,7 +257,8 @@ Q_REQUIRED_RESULT KMIME_EXPORT bool parseQDateTime(const char *&scursor, const c
  *
  * @since 4.4
  */
-Q_REQUIRED_RESULT KMIME_EXPORT KMime::Headers::Base *extractFirstHeader(QByteArray &head);
+[[nodiscard]] KMIME_EXPORT KMime::Headers::Base *
+extractFirstHeader(QByteArray &head);
 
 /**
  * Extract the header header and the body from a complete content.
