@@ -31,7 +31,7 @@ using namespace KMime;
 namespace KMime
 {
 
-QVector<QByteArray> c_harsetCache;
+QList<QByteArray> c_harsetCache;
 bool u_seOutlookEncoding = false;
 
 QByteArray cachedCharset(const QByteArray &name)
@@ -71,18 +71,17 @@ QString nameForEncoding(Headers::contentEncoding enc)
     }
 }
 
-QVector<Headers::contentEncoding> encodingsForData(const QByteArray &data)
-{
-    QVector<Headers::contentEncoding> allowed;
+QList<Headers::contentEncoding> encodingsForData(const QByteArray &data) {
+    QList<Headers::contentEncoding> allowed;
     CharFreq cf(data);
 
     switch (cf.type()) {
     case CharFreq::SevenBitText:
         allowed << Headers::CE7Bit;
-        Q_FALLTHROUGH();
+        [[fallthrough]];
     case CharFreq::EightBitText:
         allowed << Headers::CE8Bit;
-        Q_FALLTHROUGH();
+        [[fallthrough]];
     case CharFreq::SevenBitData:
         if (cf.printableRatio() > 5.0 / 6.0) {
             // let n the length of data and p the number of printable chars.
