@@ -13,8 +13,8 @@
 #include "kmime_headers.h"
 #include "kmime_content.h"
 
+#include <QList>
 #include <QString>
-#include <QVector>
 
 namespace KMime
 {
@@ -41,7 +41,8 @@ KMIME_EXPORT extern QString nameForEncoding(KMime::Headers::contentEncoding enc)
   @param data the data to check encodings for
   @ since 4.4
 */
-Q_REQUIRED_RESULT KMIME_EXPORT QVector<KMime::Headers::contentEncoding> encodingsForData(const QByteArray &data);
+[[nodiscard]] KMIME_EXPORT QList<KMime::Headers::contentEncoding>
+encodingsForData(const QByteArray &data);
 
 /**
   * Set whether or not to use outlook compatible attachment filename encoding. Outlook
